_me = frm_blackwhite.prototype;
function frm_blackwhite(){};

_me.__constructor = async function(sAcc,sFol) {
	var bWhite = true;
	if (sFol.indexOf('Blacklist') > -1)
		bWhite = false;
	await this._draw('frm_blackwhite', 'main');
	this._title('BLACKWHITE::' + (bWhite?'WHITE':'BLACK'));
	this._acc = sAcc;
	this._fol = sFol;
	
	var me = this;

	// This function is triggered when 'OK' button is pressed
	this.EMAIL._onerror = function(b){
		me.x_btn_ok._disabled(b);
	};
	this.EMAIL._restrict(/(^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$)|(^((?!-))(xn--)?[a-z0-9][a-z0-9\-_]{0,61}[a-z0-9]{0,1}\.(xn--)?([a-z0-9-]{1,61}|[a-z0-9-]{1,30}\.[a-z]{2,})$)/);
	this.EMAIL._onsubmit = function(){
		!me.x_btn_ok._disabled() && me.x_btn_ok._onclick();
	};
	this.x_btn_ok._onclick = function() {

		var id = [sAcc, sFol],
			aValues = {'values':{}};

		storeDataFromForm(me, aValues['values']);
		
		if (aValues['values']['EMAIL'])
			WMItems.add(id, aValues, '', '','',[me,'_listFolder']);
		else
			me._destruct();
	};

	this._size(350,'auto',true);
};

_me._listFolder = function (){
	var aItems = dataSet.get('items');
	for(var sAccId in aItems)
	  for(var sFolId in aItems[sAccId]);
	  
	if (sAccId == this._acc && sFolId == this._fol) {

		var aSort = Cookie.get(['views',this._acc,this._fol,'sort']);

		gui.frm_main.main.list._serverSort({aid:this._acc,fid:this._fol},aSort['column'],aSort['type'],void 0, void 0, true, true);
	}
	this._destruct();
};